/*
 * Copyright (c) 2023-2024.
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.attachments;

import java.io.OutputStream;
import java.util.concurrent.CompletableFuture;

import org.springframework.stereotype.Service;

import de.ozgcloud.vorgang.grpc.binaryFile.GrpcBinaryFilesRequest;
import lombok.NonNull;
import lombok.RequiredArgsConstructor;
import lombok.extern.log4j.Log4j2;

@Log4j2
@Service
@RequiredArgsConstructor
public class FileRemoteService {
	private final @NonNull FileGrpcClient grpcClient;

	public OzgFile getFile(String fileId, String address) {
		var grpcFileMetadata = grpcClient.findBinaryFilesMetaData(buildGrpcBinaryFileRequest(fileId), address);

		if (!grpcFileMetadata.getFileList().isEmpty()) {
			return OzgFileMapper.fromGrpcFile(grpcFileMetadata.getFile(0));
		}

		LOG.warn("Received file id {} from {}, but findBinaryFilesMetaData returned empty file list", fileId, address);

		return null;
	}

	private GrpcBinaryFilesRequest buildGrpcBinaryFileRequest(String fileId) {
		return GrpcBinaryFilesRequest.newBuilder()
		  .addFileId(fileId)
		  .build();
	}

	CompletableFuture<String> uploadFile(OzgUploadFile uploadFile, String address) {
		var fileIdFuture = new CompletableFuture<String>();
		var request = grpcClient.uploadFile(uploadFile, address, fileIdFuture);
		LOG.debug("Grpc File Upload Request: {}", request);

		return fileIdFuture;
	}

	public void downloadFileContent(String fileId, OutputStream out, String address) {
		grpcClient.downloadFileContent(fileId, out, address);
	}
}
