/*
 * Copyright (c) 2023-2024.
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.events;

import de.ozgcloud.info.GrpcInformationRequest;
import de.ozgcloud.info.InformationServiceGrpc;
import de.ozgcloud.info.nachricht.GrpcNachricht;
import lombok.extern.log4j.Log4j2;
import net.devh.boot.grpc.client.inject.GrpcClient;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
@Log4j2
class NachrichtEventRemoteService {

	@GrpcClient("info-manager")
	InformationServiceGrpc.InformationServiceBlockingStub informationServiceBlockingClient;

	List<NachrichtEvent> getNachrichtEventsOfPostfach(String postfachId) {
		return loadEvents(postfachId).stream().map(NachrichtEventMapper::fromGrpc).toList();
	}

	private List<GrpcNachricht> loadEvents(String postfachId) {
		var request = GrpcInformationRequest.newBuilder().setPostfachId(postfachId).build();

		return informationServiceBlockingClient.getInformation(request).getNachrichtenList();
	}
}
