/*
 * Copyright (c) 2024.
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.mocks;

import de.ozgcloud.antragsraum.common.NotFoundException;
import de.ozgcloud.nachrichten.antragraum.AntragraumServiceGrpc;
import de.ozgcloud.nachrichten.antragraum.GrpcFindRueckfragenRequest;
import de.ozgcloud.nachrichten.antragraum.GrpcFindRueckfragenResponse;
import de.ozgcloud.nachrichten.antragraum.GrpcSendRueckfrageAnswerRequest;
import de.ozgcloud.nachrichten.antragraum.GrpcSendRueckfrageAnswerResponse;
import io.grpc.stub.StreamObserver;
import lombok.RequiredArgsConstructor;
import lombok.extern.log4j.Log4j2;
import net.devh.boot.grpc.server.service.GrpcService;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;

@Log4j2
@GrpcService
@ConditionalOnProperty(prefix = "grpc", name = "ozg_service.stubs.enabled")
@RequiredArgsConstructor
public class AntragsraumGrpcServiceStub extends AntragraumServiceGrpc.AntragraumServiceImplBase {
    private final StubDataRepository dataRepository;

    @Override
    public void findRueckfragen(GrpcFindRueckfragenRequest request,
                                StreamObserver<GrpcFindRueckfragenResponse> responseObserver) {
        try {
            var response = dataRepository.getRueckfragenResponse(request.getPostfachId());
            LOG.info("Send response " + response);
            responseObserver.onNext(response);

            responseObserver.onCompleted();
        } catch (NotFoundException e) {
            LOG.error(e);
            responseObserver.onError(e);
        }
    }

    @Override
    public void sendRueckfrageAnswer(GrpcSendRueckfrageAnswerRequest request,
                                     StreamObserver<GrpcSendRueckfrageAnswerResponse> responseObserver) {
        LOG.info("Sending answer to OZG-CLOUD: " + request);
        var response = GrpcSendRueckfrageAnswerResponse.newBuilder().setCommandId(CommandGrpcServiceStub.ID).build();
        var res = dataRepository.addReply(request.getAnswer());

        if (res) {
            responseObserver.onNext(response);

            LOG.info("Send command response: " + response);
            responseObserver.onCompleted();
        } else {
            responseObserver.onError(new RuntimeException("Error saving reply"));
        }
    }
}
