/*
 * Copyright (c) 2023-2024.
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.mocks;

import java.io.ByteArrayInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;

import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;

import com.google.protobuf.ByteString;

import de.ozgcloud.vorgang.grpc.binaryFile.BinaryFileServiceGrpc;
import de.ozgcloud.vorgang.grpc.binaryFile.GrpcBinaryFilesRequest;
import de.ozgcloud.vorgang.grpc.binaryFile.GrpcFindFilesResponse;
import de.ozgcloud.vorgang.grpc.binaryFile.GrpcGetBinaryFileDataRequest;
import de.ozgcloud.vorgang.grpc.binaryFile.GrpcGetBinaryFileDataResponse;
import de.ozgcloud.vorgang.grpc.binaryFile.GrpcUploadBinaryFileRequest;
import de.ozgcloud.vorgang.grpc.binaryFile.GrpcUploadBinaryFileResponse;
import io.grpc.stub.StreamObserver;
import lombok.RequiredArgsConstructor;
import lombok.extern.log4j.Log4j2;
import net.devh.boot.grpc.server.service.GrpcService;

@Log4j2
@GrpcService
@ConditionalOnProperty(prefix = "grpc", name = "ozg_service.stubs.enabled")
@RequiredArgsConstructor
public class BinaryFileGrpcServiceStub extends BinaryFileServiceGrpc.BinaryFileServiceImplBase {
	public static final int CHUNK_SIZE = 255 * 1024;
	private final StubDataRepository stubDataRepository;

	@Override
	public StreamObserver<GrpcUploadBinaryFileRequest> uploadBinaryFileAsStream(StreamObserver<GrpcUploadBinaryFileResponse> responseObserver) {
		return new UploadStreamObserverStub(responseObserver, stubDataRepository);
		/*var fileId = stubDataRepository.addFile(fileUploadRequest.getMetadata());
		var fileIdFuture = CompletableFuture.completedFuture(fileId);
		var streamer = new ChunkedFileSender(uploadBinaryFileRequest.getUploadStream(), CHUNK_SIZE, this::buildChunkRequest, metadataRequest);
		return new BinaryFileUploadStreamObserver(fileIdFuture, streamer);*/
	}

	@Override
	public void getBinaryFileContent(GrpcGetBinaryFileDataRequest request, StreamObserver<GrpcGetBinaryFileDataResponse> responseObserver) {
		var contentOpt = stubDataRepository.getFileContent(request.getFileId());

		contentOpt.ifPresentOrElse(content -> {
			try (ByteArrayInputStream buffer = new ByteArrayInputStream(content)) {
				byte[] chunk = new byte[CHUNK_SIZE];
				int read;
				while ((read = buffer.read(chunk)) > 0) {
					LOG.info("Send chunk. Length: {}", read);
					responseObserver.onNext(GrpcGetBinaryFileDataResponse.newBuilder()
					  .setFileContent(ByteString.copyFrom(chunk)).build());
				}
			} catch (IOException e) {
				responseObserver.onError(e);
			}
		}, () -> {
			try (ByteArrayInputStream bais = new ByteArrayInputStream(GrpcDataCreator.FILE_CONTENT)) {
				responseObserver.onNext(GrpcGetBinaryFileDataResponse.newBuilder()
				  .setFileContent(ByteString.copyFrom(bais.readAllBytes())).build());
			} catch (IOException e) {
				responseObserver.onError(e);
			}
		});

		responseObserver.onCompleted();
	}

	@Override
	public void findBinaryFilesMetaData(GrpcBinaryFilesRequest request, StreamObserver<GrpcFindFilesResponse> responseObserver) {
		final String fileId = request.getFileId(0);
		var fileOpt = stubDataRepository.getFileMetaData(fileId);

		fileOpt.ifPresentOrElse(file -> {
			responseObserver.onNext(
			  GrpcFindFilesResponse.newBuilder().addFile(DataMapper.fromGrpcUploadBinaryFileMetaData(file, fileId)).build());
			responseObserver.onCompleted();
		}, () -> {
			LOG.error("File with id {} not found.", fileId);
			responseObserver.onError(new FileNotFoundException("File " + fileId + " not found in db"));
		});
	}
}
