/*
 * Copyright (c) 2023-2024.
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.mocks;

import de.ozgcloud.vorgang.grpc.command.CommandServiceGrpc;
import de.ozgcloud.vorgang.grpc.command.GrpcCommand;
import de.ozgcloud.vorgang.grpc.command.GrpcGetCommandRequest;
import io.grpc.stub.StreamObserver;
import lombok.extern.log4j.Log4j2;
import net.devh.boot.grpc.server.service.GrpcService;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;

import java.util.UUID;

@GrpcService
@Log4j2
@ConditionalOnProperty(prefix = "grpc", name = "ozg_service.stubs.enabled")
public class CommandGrpcServiceStub extends CommandServiceGrpc.CommandServiceImplBase {
    static final String ID = UUID.randomUUID().toString();
    static final String STATUS_SEND = "SEND";
    static final String STATUS_FINISHED = "FINISHED";
    static final String STATUS_PENDING = "PENDING";

    @Override
    public void getCommand(GrpcGetCommandRequest request, StreamObserver<GrpcCommand> observer) {
        if (ID.equals(request.getId())) {
            LOG.info("Finishing command {}", request.getId());
            observer.onNext(GrpcCommand.newBuilder().setStatus(STATUS_FINISHED).setId(ID).build());
        } else {
            LOG.info("Pending command {}", request.getId());
            observer.onNext(GrpcCommand.newBuilder()
                    .setStatus(STATUS_PENDING).setId(ID).build());
        }
        observer.onCompleted();
    }
}
