/*
 * Copyright (c) 2023-2024.
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.mocks;

import de.ozgcloud.nachrichten.antragraum.GrpcRueckfrage;
import de.ozgcloud.vorgang.grpc.binaryFile.GrpcBinaryFile;
import de.ozgcloud.vorgang.grpc.file.GrpcOzgFile;
import lombok.AccessLevel;
import lombok.NoArgsConstructor;
import lombok.extern.log4j.Log4j2;
import org.apache.commons.lang3.RandomStringUtils;
import org.springframework.http.MediaType;

import java.nio.charset.StandardCharsets;

@NoArgsConstructor(access = AccessLevel.PRIVATE)
@Log4j2
class GrpcDataCreator {
	static final String POSTFACH_ID_1 = "28721c6f-b78f-4d5c-a048-19fd2fc429d2";
	static final String POSTFACH_ID_2 = "12345c6a-b78f-4d5c-a048-19fd2fc400a1";
	static final String NACHRICHT_ID_1_0 = "6358fd4146811d04010f44d0";
	static final String NACHRICHT_ID_2_0 = "6358fd4446811d04010f44da";
	static final String NACHRICHT_ID_2_1 = "6358fd4446811d04010f44db";
	static final String VORGANG_ID_1 = "6358fd0bee7a051389cdd787";
	static final String VORGANG_ID_2 = "6358fd3f46811d04010f44c7";
	public static final String TEXT = """
			Lorem ipsum dolor sit amet, consetetur sadipscing elitr,
			 sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat,
			 sed diam voluptua. At vero eos et accusam et justo duo dolores et ea rebum.
			 
			 Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet.
			 Lorem ipsum dolor sit amet, consetetur sadipscing elitr.
			""";
	static final String FILE_ID_1 = "6358fd0bee7a051389cdd788";
	static final String FILE_ID_2 = "6358fd0bee7a051389cdd799";
	static final String FILE_NAME = "TestDokument.txt";
	static final byte[] FILE_CONTENT = TEXT.getBytes(StandardCharsets.UTF_8);
	static final String VORGANG_TITLE = "Vorgang title ";

	static GrpcRueckfrage.Builder getRueckfrageBuilder(String vorgangId) {
		var builder = GrpcRueckfrage.newBuilder()
				.setId(RandomStringUtils.randomAlphanumeric(16))
				.setVorgangId(vorgangId)
				.setText(TEXT)
				.setVorgangName(VORGANG_TITLE + vorgangId)
				.setSentAt("2022-10-26T09:26:25")
				.clearAnswers();
		if (vorgangId.equals(VORGANG_ID_1)) {
			builder.addAttachmentFileId(FILE_ID_1);
			builder.setId(NACHRICHT_ID_1_0);
		} else if (vorgangId.equals(VORGANG_ID_2)) {
			builder.setId(NACHRICHT_ID_2_0);
			builder.addAttachmentFileId(FILE_ID_2);
		}

		return builder;
	}

	static GrpcBinaryFile createBinaryFile(String fileId) {
		return GrpcBinaryFile.newBuilder()
				.setContentType(MediaType.TEXT_PLAIN_VALUE)
				.setSize(FILE_CONTENT.length)
				.setId(fileId)
				.setName(FILE_NAME)
				.build();
	}

	static GrpcOzgFile createFile(String fileId) {
		return GrpcOzgFile.newBuilder()
				.setContentType(MediaType.TEXT_PLAIN_VALUE)
				.setSize(FILE_CONTENT.length)
				.setId(fileId)
				.setName(FILE_NAME)
				.build();
	}
}
