/*
 * Copyright (c) 2024.
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.mocks;

import java.util.Date;
import java.util.List;
import java.util.UUID;

import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.Authentication;
import org.springframework.stereotype.Component;

import de.ozgcloud.antragsraum.security.DefaultRole;
import de.ozgcloud.antragsraum.security.JwtTokenProvider;
import de.ozgcloud.antragsraum.security.User;
import de.ozgcloud.antragsraum.security.UserTrustLevel;
import lombok.RequiredArgsConstructor;
import lombok.extern.log4j.Log4j2;

@Log4j2
@Component
@RequiredArgsConstructor
public class JwtTokenWrapper {
	public static final String POSTKORB_HANDLE = "28721c6f-b78f-4d5c-a048-19fd2fc429d2";
	public static final String USER_ID = UUID.randomUUID().toString();
	public static final String USER_NAME = "test";
	public static final String SAML_TOKEN_DUMMY = "saml-token-dummy";
	private final JwtTokenProvider tokenProvider;

	Authentication wrap(String accessToken) {
		LOG.info("Got token: " + accessToken);
		User user = User.builder().id(USER_ID)
		  .firstName(USER_NAME)
		  .lastName(USER_NAME)
		  .samlToken(SAML_TOKEN_DUMMY)
		  .username(USER_NAME)
		  .postkorbHandle(POSTKORB_HANDLE)
		  .trustLevel(UserTrustLevel.STORK_QAA_LEVEL_3)
		  .tokenExpiresAt(new Date())
		  .build();
		return new UsernamePasswordAuthenticationToken(user.getId(), tokenProvider.generate(user), List.of(new DefaultRole()));
	}
}
