/*
 * Copyright (c) 2023-2024.
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.mocks;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Builder;

@Builder(toBuilder = true)
public record MockEvent(
		@Schema(description = "The postkorbHandle",
				name = "postkorbHandle",
				type = "string",
				example = "28721c6f-b78f-4d5c-a048-19fd2fc429d2"
		)
		String postkorbHandle,
		@Schema(description = "The Vorgang Id",
				name = "vorgangId",
				type = "string",
				example = "abcd1c6f-b78f-4d5c-a048-19fd2fc42xxx"
		)
		String vorgangId,
		@Schema(description = "Address of the OZG-Cloud instance. Should be 'static://localhost:9090' other values will produce errors!",
				name = "address",
				type = "string",
				example = "static://localhost:9090"
		)
		String address,
		@Schema(description = "The Vorgang title of the message send by the clerk. Optional if empty the example title is used.",
				name = "clerkMessageTitle",
				type = "string",
				example = "Vorgang title <id of the reply message>"
		)
		String clerkMessageTitle,
		@Schema(description = "The text of the message send by the clerk. Optional, if empty an example text is used.",
				name = "clerkMessageText",
				type = "string",
				example = "Lorem ipsum dolor sit amet, consetetur sadipscing elitr,\n sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat,\\n sed diam voluptua. At vero eos et accusam et justo duo dolores et ea rebum.\\n\\n Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet.\\n Lorem ipsum dolor sit amet, consetetur sadipscing elitr."
		)
		String clerkMessageText,

		@Schema(description = "The timestamp when the clerk message has been send. When not set the current time and date is used",
				name = "sendDateTime",
				type = "String",
				example = "2023-12-01T12:23:25.000"
		)
		String sendDateTime,
		@Schema(description = "Add the test attachments to the event. Defaults to 0, which means no attachments",
				name = "attachmentCount",
				type = "integer",
				example = "0")
		int attachmentCount) {
}
