/*
 * Copyright (c) 2023-2024.
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.nachricht;

import java.util.List;

import jakarta.validation.constraints.Min;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.Size;

import org.springframework.validation.annotation.Validated;

import com.fasterxml.jackson.annotation.JsonInclude;

import de.ozgcloud.antragsraum.attachments.OzgFile;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Builder;

@JsonInclude(JsonInclude.Include.NON_NULL)
@Builder(toBuilder = true)
@Validated
public record Nachricht(
  @Schema(description = "The address of the ozg-cloud instance base64 encoded", name = "id", type = "string", example = "1258ad3f46811d04010f22ab")
  @NotBlank
  String id,
  @Schema(description = "The address of the ozg-cloud instance", name = "address", type = "string", example = "static://localhost:9090")
  @NotBlank
  String address,
  @Schema(description = "The date the Rueckfrage has been send.")
  @Min(0)
  long date,
  @Schema(description = "The title of the topic. This is the title of the Vorgang",
	name = "topicTitle",
	type = "string",
	example = "Vorgang Hundesteuer Antrag"
  )
  @Size(max = 2048, message = "title too long")
  String topicTitle,
  @Size(max = 500000, message = "message too long")
  String message,
  @Schema(description = "The id of the postfach. For BayernID this is the PostkorbHandle",
	name = "postfachId",
	type = "string",
	example = "28721c6f-b78f-4d5c-a048-19fd2fc429d2"
  )
  @Size(max = 64, message = "postfach id to long")
  String postfachId,
  @Schema(description = "The id of the Vorgang the Rueckfrage belongs to",
	name = "vorgangId",
	type = "string",
	example = "8523ad3f46811d04010f6654"
  )
  @Size(max = 64, message = "vongang id id to long")
  String vorgangId,
  @Schema(description = "The reply option, not used right now always set 'ALLOWED'",
	name = "vorgangId",
	type = "ReplyOption",
	example = "ALLOWED"
  )
  ReplyOption replyOption,
  @Schema(description = "The list of the attached files.")
  List<OzgFile> attachments,
  @Schema(hidden = true)
  List<ReplyNachricht> replyNachrichten,
  @Schema(description = "The trust level of the Rueckfrage",
	name = "trustLevel",
	type = "NachrichtTrustLevel"
  )
  NachrichtTrustLevel trustLevel) {
}
