/*
 * Copyright (c) 2024.   Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten
 * des Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung.
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.nachricht;

import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.web.authentication.session.SessionAuthenticationException;
import org.springframework.stereotype.Service;

import de.ozgcloud.antragsraum.security.User;
import de.ozgcloud.antragsraum.security.UserTrustLevel;

@Service
public class NachrichtenTrustLevelService {
	boolean nachrichtMatchesUserTrustLevel(NachrichtTrustLevel nachrichtTrustLevel) {
		var userTrustLevel = getCurrentUser().getTrustLevel();
		if (userTrustLevel == null) {
			return false;
		}

		if (nachrichtTrustLevel == null || NachrichtTrustLevel.LOW.equals(nachrichtTrustLevel)) {
			return true;
		}

		if (UserTrustLevel.STORK_QAA_LEVEL_4.equals(userTrustLevel)) {
			return true;
		}

		if (UserTrustLevel.STORK_QAA_LEVEL_3.equals(userTrustLevel)) {
			return NachrichtTrustLevel.SUBSTANTIAL.equals(nachrichtTrustLevel);
		}

		return false;
	}

	private User getCurrentUser() {
		var authentication = SecurityContextHolder.getContext().getAuthentication();
		if (authentication != null && authentication.getPrincipal() instanceof UserDetails) {
			return (User) authentication.getPrincipal();
		}

		throw new SessionAuthenticationException("Current user is null");
	}
}
