/*
 * Copyright (c) 2023-2024.
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.nachricht;

import java.util.List;

import jakarta.validation.constraints.Min;
import jakarta.validation.constraints.NotEmpty;
import jakarta.validation.constraints.Size;

import org.springframework.validation.annotation.Validated;

import com.fasterxml.jackson.annotation.JsonInclude;

import de.ozgcloud.antragsraum.attachments.OzgFile;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Builder;

@JsonInclude(JsonInclude.Include.NON_NULL)
@Builder(toBuilder = true)
@Validated
public record ReplyNachricht(
  @Schema(description = "The id of the postfach",
	name = "postfachId",
	type = "string",
	example = "28721c6f-b78f-4d5c-a048-19fd2fc429d2"
  )
  String postfachId,
  @Schema(description = "The address of the OZG-Cloud instanz the reply belongs to",
	name = "address",
	type = "string",
	example = "static://utopia.sh.ozg-cloud.de:9090"
  )
  String address,
  @Schema(description = "The encoded address of the OZG-Cloud instanz the reply belongs to",
	name = "id",
	type = "string",
	example = "c3RhdGljOi8vdXRvcGlhLnNoLm96Zy1jbG91ZC5kZTo5MDkw"
  )
  @NotEmpty
  String id,
  @Schema(description = "The answer to the rueckfrage.",
	name = "message",
	type = "string",
	example = "Im Anhang sind die Dokumente"
  )
  @Size(max = 500000, message = "message too long")
  String message,
  @Schema(description = "The answered date. Only set when displaying an already answered Rueckfrage. Will be set by the OZG-Cloud")
  @Min(0)
  long date,
  @Schema(description = "The list of the attached file ids. Only the file id is used when sending the reply, The other values are set by the backend")
  List<OzgFile> attachments) {
}
