/*
 * Copyright (c) 2023-2024.
 * Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.antragsraum.attachments;

import static org.assertj.core.api.Assertions.*;

import java.io.ByteArrayOutputStream;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.TimeoutException;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.boot.test.mock.mockito.SpyBean;
import org.springframework.test.annotation.DirtiesContext;
import org.springframework.test.context.junit.jupiter.SpringJUnitConfig;

import lombok.extern.log4j.Log4j2;

@SpringBootTest(properties = {
  "grpc.server.inProcessName=test3",
  "grpc.server.port=-1"
})
@SpringJUnitConfig(classes = { FileGrpcTestConfiguration.class })
@DirtiesContext
@Log4j2
public class FileRemoteServiceITCase {
	private static final String CHANNEL_ADDRESS = "in-process:test3";

	@SpyBean
	private FileRemoteService fileRemoteService;

	@Nested
	class TestFileUpload {

		@Test
		@DirtiesContext
		void shouldUploadFile() {
			var idFuture = fileRemoteService.uploadFile(OzgUploadFileTestFactory.create(), CHANNEL_ADDRESS);

			try {
				assertThat(idFuture.get(1, TimeUnit.SECONDS)).isEqualTo(FileTestProperties.FILE_ID);
			} catch (InterruptedException | ExecutionException | TimeoutException e) {
				fail(e.getMessage());
			}
		}
	}

	@Nested
	class TestGetFile {
		@Test
		@DirtiesContext
		void shouldGetFile() {
			var file = fileRemoteService.getFile(FileTestProperties.FILE_ID, CHANNEL_ADDRESS);

			assertThat(file).isNotNull();
		}

		@Test
		@DirtiesContext
		void shouldHaveFileMetaData() {
			var file = fileRemoteService.getFile(FileTestProperties.FILE_ID, CHANNEL_ADDRESS);

			assertThat(file).isEqualTo(OzgFileTestFactory.createOzgFile());
		}
	}

	@Nested
	class TestGetFileContent {
		@Test
		@DirtiesContext
		void shouldGetFileContent() {
			var out = new ByteArrayOutputStream();
			fileRemoteService.downloadFileContent(FileTestProperties.FILE_ID, out, CHANNEL_ADDRESS);

			assertThat(out.size()).isEqualTo(FileTestProperties.DATA.length);
		}
	}
}
