/*
 * Copyright (c) 2023-2024.
 * Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.attachments;

import static de.ozgcloud.antragsraum.attachments.FileTestProperties.CONTENT_TYPE;
import static de.ozgcloud.antragsraum.attachments.FileTestProperties.FILE_ID;
import static de.ozgcloud.antragsraum.attachments.FileTestProperties.FILE_NAME;
import static de.ozgcloud.antragsraum.attachments.FileTestProperties.FILE_SIZE;
import static org.assertj.core.api.Assertions.assertThat;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;

class OzgFileMapperTest {

    @Nested
    class TestMappingGrpcOzgFile {
        @Test
        void shouldHaveFileName() {
            var file = OzgFileMapper.fromGrpcFile(OzgFileTestFactory.createGrpcFile());

            assertThat(file.fileName()).isEqualTo(FILE_NAME);
        }

        @Test
        void shouldHaveFileSize() {
            var file = OzgFileMapper.fromGrpcFile(OzgFileTestFactory.createGrpcFile());

            assertThat(file.fileSize()).isEqualTo(FILE_SIZE);
        }

        @Test
        void shouldHaveContentType() {
            var file = OzgFileMapper.fromGrpcFile(OzgFileTestFactory.createGrpcFile());

            assertThat(file.contentType()).isEqualTo(CONTENT_TYPE);
        }

        @Test
        void shouldHaveFileId() {
            var file = OzgFileMapper.fromGrpcFile(OzgFileTestFactory.createGrpcFile());

            assertThat(file.id()).isEqualTo(FILE_ID);
        }
    }
}