/*
 * Copyright (c) 2023-2024.
 * Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.antragsraum.common;

import net.devh.boot.grpc.client.config.GrpcChannelsProperties;
import net.devh.boot.grpc.client.config.NegotiationType;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.junit.jupiter.MockitoExtension;
import org.springframework.test.util.ReflectionTestUtils;

import static org.assertj.core.api.Assertions.*;

@ExtendWith(MockitoExtension.class)
class ChannelPropertiesFactoryTest {
    public static final String CHANNEL_ADDRESS = "static://localhost:9090";
    private final ChannelPropertiesFactory channelPropertiesFactory = new ChannelPropertiesFactory(new GrpcChannelsProperties());

    @Test
    void shouldCreateChannel() {
        var channel = channelPropertiesFactory.createChannelProperties(CHANNEL_ADDRESS);
        assertThat(channel).isNotNull();
    }

    @Test
    void shouldCreateChannelWithNegotiationType() {
        ReflectionTestUtils.setField(channelPropertiesFactory, "negotiationType", "TLS");
        var channel = channelPropertiesFactory.createChannelProperties(CHANNEL_ADDRESS);
        assertThat(channel.getNegotiationType()).isEqualTo(NegotiationType.TLS);
    }

    @Test
    void shouldGetChannel() {
        var channel = channelPropertiesFactory.getChannel(CHANNEL_ADDRESS);
        assertThat(channel).isNotNull();
    }

    @Test
    void shouldGetRawChannel() {
        var channel = channelPropertiesFactory.getRawChannel(CHANNEL_ADDRESS);
        assertThat(channel).isNotNull();
    }

    @Test
    void shouldGetDefaultScheme() {
        var scheme = channelPropertiesFactory.getDefaultScheme();
        assertThat(scheme).isEqualTo("inProcess");
    }
}