/*
 * Copyright (c) 2023-2024.
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.events;

import static org.assertj.core.api.Assertions.assertThat;
import static org.mockito.Mockito.any;
import static org.mockito.Mockito.when;

import de.ozgcloud.info.GrpcInformationRequest;
import de.ozgcloud.info.GrpcInformationResponse;
import de.ozgcloud.info.InformationServiceGrpc;
import de.ozgcloud.info.nachricht.GrpcNachricht;
import java.util.List;
import java.util.UUID;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;
import org.mockito.junit.jupiter.MockitoExtension;

@ExtendWith(MockitoExtension.class)
class NachrichtEventRemoteServiceTest {

    @Spy
    @InjectMocks
    private NachrichtEventRemoteService remoteService;
    @Mock
    private InformationServiceGrpc.InformationServiceBlockingStub informationServiceBlockingClient;

    @Nested
    class TestInformationAvailable {

        private final String postfachId = UUID.randomUUID().toString();
        private final List<GrpcNachricht> nachrichten =
            List.of(GrpcNachrichtTestFactory.createBuilder().setPostfachId(postfachId).build());

        @BeforeEach
        void init() {
            when(informationServiceBlockingClient.getInformation(any(GrpcInformationRequest.class)))
                .thenReturn(GrpcInformationResponse.newBuilder().addAllNachrichten(nachrichten).build());
        }

        @Test
        void shouldLoadNachrichtEvents() {
            var events = remoteService.getNachrichtEventsOfPostfach(postfachId);

            assertThat(events).hasSize(1);
        }

        @Test
        void shouldHavePostfachId() {
            var events = remoteService.getNachrichtEventsOfPostfach(postfachId);

            assertThat(events.get(0).postfachId()).isEqualTo(postfachId);
        }
    }

    @Nested
    class TestNoInformationAvailable {
        private final String postfachId = UUID.randomUUID().toString();
        private final List<GrpcNachricht> nachrichten = List.of();

        @BeforeEach
        void init() {
            when(informationServiceBlockingClient.getInformation(any(GrpcInformationRequest.class)))
                .thenReturn(GrpcInformationResponse.newBuilder().addAllNachrichten(nachrichten).build());
        }

        @Test
        void shouldLoadEmptyNachrichtEvents() {
            var events = remoteService.getNachrichtEventsOfPostfach(postfachId);

            assertThat(events).hasSize(0);
        }
    }
}