/*
 * Copyright (c) 2023-2024.
 * Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.antragsraum.nachricht;

import java.util.UUID;

import de.ozgcloud.nachrichten.postfach.GrpcDirection;
import de.ozgcloud.nachrichten.postfach.GrpcPostfachAddress;
import de.ozgcloud.nachrichten.postfach.GrpcPostfachMail;
import de.ozgcloud.vorgang.common.GrpcObject;
import de.ozgcloud.vorgang.common.GrpcProperty;

public class GrpcPostfachMailTestFactory {
	static final String NACHRICHT_ID = UUID.randomUUID().toString();
	static final String VORGANG_ID = NachrichtTestFactory.VORGANG_ID;

	static final String POSTFACH_ID_FIELD = "postfachId";

	static GrpcPostfachMail create() {
		return createBuilder().build();
	}

	static GrpcPostfachMail.Builder createBuilder() {
		return GrpcPostfachMail.newBuilder()
		  .setId(NACHRICHT_ID)
		  .setVorgangId(VORGANG_ID)
		  .setPostfachAddress(createPostfachAddress())
		  .setMailBody(NachrichtTestFactory.TEXT)
		  .setSubject(NachrichtTestFactory.VORGANG_TITLE)
		  .setDirection(GrpcDirection.OUT)
		  .setSentAt(NachrichtTestFactory.DATE_STRING)
		  .setCreatedAt(NachrichtTestFactory.DATE_STRING)
		  .setReplyOption(NachrichtTestFactory.REPLY_FORBIDDEN.name())
		  .addAttachment(NachrichtTestFactory.ATTACHMENT_ID_1)
		  .addAttachment(NachrichtTestFactory.ATTACHMENT_ID_2);
	}

	private static GrpcPostfachAddress createPostfachAddress() {
		return GrpcPostfachAddress.newBuilder()
		  .setIdentifier(GrpcObject.newBuilder()
			.addProperty(
			  GrpcProperty.newBuilder()
				.setName(POSTFACH_ID_FIELD)
				.addValue(NachrichtTestFactory.POSTFACH_ID).build()
			).build()
		  ).build();
	}
}
