/*
 * Copyright (c) 2023-2024.
 * Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.antragsraum.nachricht;

import static org.assertj.core.api.Assertions.*;

import java.util.Collections;
import java.util.List;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;

class NachrichtHeaderMapperTest {
	@Nested
	class TestFromNachricht {
		private final Nachricht nachricht = NachrichtTestFactory.createNachricht();

		@Test
		void shouldMapNachrichtId() {
			var nachrichtHeader = NachrichtHeaderMapper.fromNachricht(nachricht);

			assertThat(nachrichtHeader.id()).isEqualTo(NachrichtTestFactory.ID);
		}

		@Test
		void shouldMapAddress() {
			var nachrichtHeader = NachrichtHeaderMapper.fromNachricht(nachricht);

			assertThat(nachrichtHeader.address()).isEqualTo(NachrichtTestFactory.ADDRESS);
		}

		@Test
		void shouldMapVorgangId() {
			var nachrichtHeader = NachrichtHeaderMapper.fromNachricht(nachricht);

			assertThat(nachrichtHeader.vorgangId()).isEqualTo(NachrichtTestFactory.VORGANG_ID);
		}

		@Test
		void shouldMapVorgangName() {
			var nachrichtHeader = NachrichtHeaderMapper.fromNachricht(nachricht);

			assertThat(nachrichtHeader.topicTitle()).isEqualTo(NachrichtTestFactory.VORGANG_TITLE);
		}

		@Test
		void shouldMapCreationDate() {
			var nachrichtHeader = NachrichtHeaderMapper.fromNachricht(nachricht);

			assertThat(nachrichtHeader.date()).isEqualTo(NachrichtTestFactory.DATE);
		}

		@Test
		void shouldMapLastAnsweredDate() {
			var nachrichtHeader = NachrichtHeaderMapper.fromNachricht(nachricht);

			assertThat(nachrichtHeader.lastAnsweredDate()).isEqualTo(NachrichtTestFactory.DATE);
		}

		@Test
		void shouldMapTrustLevel() {
			var nachrichtHeader = NachrichtHeaderMapper.fromNachricht(nachricht);

			assertThat(nachrichtHeader.trustLevel()).isEqualTo(NachrichtTrustLevel.LOW);
		}
	}

	@Nested
	class TestGetLatestReplyDate {
		@Test
		void shouldHaveNoDate() {
			var nachricht = Nachricht.builder().replyNachrichten(Collections.emptyList()).build();
			var result = NachrichtHeaderMapper.getLatestReplyDate(nachricht);

			assertThat(result).isNull();
		}

		@Test
		void shouldReturnLatestDate() {
			var replyNachrichten = List.of(
			  ReplyNachricht.builder().date(NachrichtTestFactory.DATE).build(),
			  ReplyNachricht.builder().date(NachrichtTestFactory.DATE - 1000).build()
			);
			var nachricht = Nachricht.builder().replyNachrichten(replyNachrichten).build();
			var result = NachrichtHeaderMapper.getLatestReplyDate(nachricht);

			assertThat(result).isEqualTo(NachrichtTestFactory.DATE);
		}
	}
}