/*
 * Copyright (c) 2023-2024.
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.antragsraum.nachricht;

import static org.mockito.Mockito.*;

import org.springframework.boot.autoconfigure.ImportAutoConfiguration;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import com.google.common.collect.ImmutableList;

import de.ozgcloud.antragsraum.attachments.FileRemoteService;
import de.ozgcloud.antragsraum.callcontext.CallContextAttachingInterceptor;
import de.ozgcloud.antragsraum.callcontext.ContextService;
import de.ozgcloud.antragsraum.common.AuthenticationHelper;
import de.ozgcloud.antragsraum.common.ChannelPropertiesFactory;
import lombok.NonNull;
import net.devh.boot.grpc.client.autoconfigure.GrpcClientAutoConfiguration;
import net.devh.boot.grpc.client.autoconfigure.GrpcClientHealthAutoConfiguration;
import net.devh.boot.grpc.client.autoconfigure.GrpcClientMetricAutoConfiguration;
import net.devh.boot.grpc.client.autoconfigure.GrpcClientSecurityAutoConfiguration;
import net.devh.boot.grpc.client.autoconfigure.GrpcClientTraceAutoConfiguration;
import net.devh.boot.grpc.client.config.GrpcChannelsProperties;
import net.devh.boot.grpc.client.interceptor.GlobalClientInterceptorRegistry;
import net.devh.boot.grpc.common.autoconfigure.GrpcCommonCodecAutoConfiguration;
import net.devh.boot.grpc.common.autoconfigure.GrpcCommonTraceAutoConfiguration;
import net.devh.boot.grpc.server.autoconfigure.GrpcServerAutoConfiguration;
import net.devh.boot.grpc.server.autoconfigure.GrpcServerFactoryAutoConfiguration;
import net.devh.boot.grpc.server.serverfactory.GrpcServerConfigurer;

@Configuration
@ImportAutoConfiguration({
  GrpcCommonCodecAutoConfiguration.class,
  GrpcCommonTraceAutoConfiguration.class,

  GrpcServerAutoConfiguration.class,
  GrpcServerFactoryAutoConfiguration.class,

  GrpcClientAutoConfiguration.class,
  GrpcClientHealthAutoConfiguration.class,
  GrpcClientMetricAutoConfiguration.class,
  GrpcClientSecurityAutoConfiguration.class,
  GrpcClientTraceAutoConfiguration.class
})
public class NachrichtenServiceGrpcTestConfiguration {
	@Bean
	AntragsraumServiceGrpc antragsraumServiceGrpcStub() {
		return new AntragsraumServiceGrpc();
	}

	@Bean
	CommandGrpcService commandGrpcServiceStub() {
		return new CommandGrpcService();
	}

	NachrichtProperties nachrichtProperties() {
		NachrichtProperties nachrichtProperties = new NachrichtProperties();
		nachrichtProperties.setSendPollInterval("PT-0.5S");
		nachrichtProperties.setSendTimeout("PT2S");
		return nachrichtProperties;
	}

	@Bean
	NachrichtenRemoteService nachrichtRemoteService() {
		return new NachrichtenRemoteService(nachrichtenGrpcClient(), nachrichtProperties(), contextService(), nachrichtMapper());
	}

	NachrichtenGrpcClient nachrichtenGrpcClient() {
		return new NachrichtenGrpcClient(initGlobalClientInterceptorRegistry(), initChannelsPropertiesFactory());
	}

	NachrichtMapper nachrichtMapper() {
		return new NachrichtMapper(mock(FileRemoteService.class));
	}

	@Bean
	public ContextService contextService() {
		return new ContextService(authenticationHelper());
	}

	@Bean
	public AuthenticationHelper authenticationHelper() {
		return new AuthenticationHelper();
	}

	private GlobalClientInterceptorRegistry initGlobalClientInterceptorRegistry() {
		GlobalClientInterceptorRegistry globalClientInterceptorRegistry = mock(GlobalClientInterceptorRegistry.class);
		when(globalClientInterceptorRegistry.getClientInterceptors()).thenReturn(
		  ImmutableList.of(new CallContextAttachingInterceptor(contextService())));

		return globalClientInterceptorRegistry;
	}

	@NonNull
	private static ChannelPropertiesFactory initChannelsPropertiesFactory() {
		return new ChannelPropertiesFactory(new GrpcChannelsProperties());
	}

	@Bean
	public GrpcServerConfigurer keepMetadataInterceptorInterceptor() {
		return serverBuilder -> serverBuilder.intercept(serverInterceptor());
	}

	@Bean
	public GrpcServerInterceptor serverInterceptor() {
		return new GrpcServerInterceptor();
	}
}
