/*
 * Copyright (c) 2023-2024.
 * Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.antragsraum.nachricht;

import static org.assertj.core.api.Assertions.*;

import java.util.List;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;

class TopicHeaderMapperTest {
	@Nested
	class TestFromNachrichten {
		private final List<Nachricht> nachrichten = List.of(NachrichtTestFactory.createNachricht(), NachrichtTestFactory.createNachricht());

		@Test
		void shouldHaveTopicHeaders() {
			var topicHeaders = TopicHeaderMapper.fromNachrichten(nachrichten);

			assertThat(topicHeaders).hasSize(2);
		}

		@Test
		void shouldMapClerkNachrichtHeader() {
			var topicHeaders = TopicHeaderMapper.fromNachrichten(nachrichten);

			assertThat(topicHeaders.get(0).getClerkMessage()).isNotNull();
			assertThat(topicHeaders.get(1).getClerkMessage()).isNotNull();
		}

		@Test
		void shouldMapVorgangId() {
			var topicHeaders = TopicHeaderMapper.fromNachrichten(nachrichten);

			assertThat(topicHeaders.get(0).getClerkMessage().id()).isEqualTo(NachrichtTestFactory.ID);
			assertThat(topicHeaders.get(1).getClerkMessage().id()).isEqualTo(NachrichtTestFactory.ID);
		}

		@Test
		void shouldMapVorgangName() {
			var topicHeaders = TopicHeaderMapper.fromNachrichten(nachrichten);

			assertThat(topicHeaders.get(0).getTopicTitle()).isEqualTo(NachrichtTestFactory.VORGANG_TITLE);
			assertThat(topicHeaders.get(1).getTopicTitle()).isEqualTo(NachrichtTestFactory.VORGANG_TITLE);
		}

		@Test
		void shouldMapTrustLevel() {
			var topicHeaders = TopicHeaderMapper.fromNachrichten(nachrichten);

			assertThat(topicHeaders.get(0).getTrustLevel()).isEqualTo(NachrichtTrustLevel.LOW);
			assertThat(topicHeaders.get(1).getTrustLevel()).isEqualTo(NachrichtTrustLevel.LOW);
		}
	}
}