/*
 * Copyright (c) 2023-2024.
 * Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.antragsraum.nachricht;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;

class TopicMapperTest {
	@Nested
	class TestFromNachricht {
		private final Nachricht nachricht = NachrichtTestFactory.createNachricht();

		@Test
		void shouldHaveTopic() {
			var topic = TopicMapper.fromNachricht(nachricht);

			assertThat(topic).isNotNull();
		}

		@Test
		void shouldMapClerkNachricht() {
			var topic = TopicMapper.fromNachricht(nachricht);

			assertThat(topic.getClerkMessage()).isNotNull();
		}

		@Test
		void shouldMapVorgangId() {
			var topic = TopicMapper.fromNachricht(nachricht);

			assertThat(topic.getClerkMessage().id()).isEqualTo(NachrichtTestFactory.ID);
		}

		@Test
		void shouldNotHaveReplyInClerkNachricht() {
			var topic = TopicMapper.fromNachricht(nachricht);

			assertThat(topic.getClerkMessage().replyNachrichten()).isNull();
		}

		@Test
		void shouldMapUserNachrichten() {
			var topic = TopicMapper.fromNachricht(nachricht);

			assertThat(topic.getUserMessages()).hasSize(1);
		}

		@Test
		void shouldMapVorgangName() {
			var topic = TopicMapper.fromNachricht(nachricht);

			assertThat(topic.getTopicTitle()).isEqualTo(NachrichtTestFactory.VORGANG_TITLE);
		}

		@Test
		void shouldMapTrustLevel() {
			var topic = TopicMapper.fromNachricht(nachricht);

			assertThat(topic.getTrustLevel()).isEqualTo(NachrichtTrustLevel.LOW);
		}
	}
}